Quantum Machines Extras
=======================

.. currentmodule:: qililab.extra.quantum_machines

.. note::

   The Quantum Machines integration is optional and lives under
   :mod:`qililab.extra.quantum_machines`. Install the
   ``quantum-machines`` extra to access these components.

.. autoclass:: QuantumMachinesCluster
   :members:
   :show-inheritance:

.. autoclass:: QuantumMachinesClusterController
   :members:
   :show-inheritance:

.. autoclass:: QuantumMachinesCompilationOutput
   :members:
   :show-inheritance:

.. autoclass:: QuantumMachinesCompiler
   :members:
   :show-inheritance:

.. autoclass:: QuantumMachinesMeasurementResult
   :members:
   :show-inheritance:
